api documentation: https://macrobond.github.io/macrobond-data-api/

fetching a time series: https://github.com/macrobond/macrobond-api-examples/blob/main/Python%20Data%20API%20-%20Data%2B%20%26%20Data%20Feed/1.2%20-%20Macrobond%20Data%20API%20-%20Fetching%20a%20Time%20Series.ipynb

fetching multiple time series: https://github.com/macrobond/macrobond-api-examples/blob/main/Python%20Data%20API%20-%20Data%2B%20%26%20Data%20Feed/1.3%20-%20Macrobond%20Data%20API%20-%20Fetching%20multiple%20Time%20Series.ipynb

aligning multiple time series: https://github.com/macrobond/macrobond-api-examples/blob/main/Python%20Data%20API%20-%20Data%2B%20%26%20Data%20Feed/3.1%20-%20Macrobond%20Data%20API%20-%20Aligning%20multiple%20Time%20Series.ipynb

